@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Devel::PartialDump; # git description: v0.18-5-g7d2520e
+package Devel::PartialDump; # git description: v0.19-3-ga398185
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Partial dumping of data structures, optimized for argument printing.
 # KEYWORDS: development debugging dump dumper diagnostics deep data structures
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Carp ();
 use Scalar::Util qw(looks_like_number reftype blessed);
@@ -42,7 +42,7 @@ use Sub::Exporter -setup => {
 sub replacement_caller_info {
     my $i = shift(@_) + 1;
 
-    package DB; # git description: v0.18-5-g7d2520e
+    package DB; # git description: v0.19-3-ga398185
     my %call_info;
     @call_info{
     qw(pack file line sub has_args wantarray evaltext is_require)
@@ -327,7 +327,7 @@ Devel::PartialDump - Partial dumping of data structures, optimized for argument
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -604,7 +604,7 @@ L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Florian Ragwitz Steven Lee Jesse Luehrs David Golden Leo Lapworth
+=for stopwords Karen Etheridge Florian Ragwitz Steven Lee Leo Lapworth Jesse Luehrs David Golden Paul Howarth
 
 =over 4
 
@@ -622,6 +622,10 @@ Steven Lee <stevenwh.lee@gmail.com>
 
 =item *
 
+Leo Lapworth <web@web-teams-computer.local>
+
+=item *
+
 Jesse Luehrs <doy@tozt.net>
 
 =item *
@@ -630,7 +634,7 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Leo Lapworth <web@web-teams-computer.local>
+Paul Howarth <paul@city-fan.org>
 
 =back
 
